@@ -142,7 +142,6 @@ QmlMetadata *FilterController::metadata(const QString &id)
 
 QmlMetadata *FilterController::metadataForService(Mlt::Service *service)
 {
-    QmlMetadata *meta = nullptr;
     QString uniqueId = service->get(kShotcutFilterProperty);
 
     // Fallback to mlt_service for legacy filters
@@ -255,12 +254,13 @@ void FilterController::setCurrentFilter(int attachedIndex)
     }
 
     QmlMetadata *meta = m_attachedModel.getMetadata(m_currentFilterIndex);
-    QmlFilter *filter = 0;
+    QmlFilter *filter = nullptr;
     if (meta) {
         emit currentFilterChanged(nullptr, nullptr, QmlFilter::NoCurrentFilter);
-        m_mltService = m_attachedModel.getService(m_currentFilterIndex);
-        if (!m_mltService.is_valid())
+        std::unique_ptr<Mlt::Service> service(m_attachedModel.getService(m_currentFilterIndex));
+        if (!service || !service->is_valid())
             return;
+        m_mltService = Mlt::Service(service->get_service());
         filter = new QmlFilter(m_mltService, meta);
         filter->setIsNew(m_mltService.get_int(kNewFilterProperty));
         m_mltService.clear(kNewFilterProperty);
@@ -432,3 +432,24 @@ void FilterController::addOrEditFilter(Mlt::Filter *filter, const QStringList &k
     }
     setCurrentFilter(serviceIndex);
 }
+
+void FilterController::setTrackTransitionService(const QString &service)
+{
+    if (service == QStringLiteral("qtblend")) {
+        m_metadataModel.setHidden("qtBlendMode", false);
+        m_metadataModel.setHidden("blendMode", true);
+        m_metadataModel.setHidden("movitBlendMode", true);
+    } else if (service == QStringLiteral("frei0r.cairoblend")) {
+        m_metadataModel.setHidden("qtBlendMode", true);
+        m_metadataModel.setHidden("blendMode", false);
+        m_metadataModel.setHidden("movitBlendMode", true);
+    } else if (service == QStringLiteral("movit.overlay")) {
+        m_metadataModel.setHidden("qtBlendMode", true);
+        m_metadataModel.setHidden("blendMode", true);
+        m_metadataModel.setHidden("movitBlendMode", false);
+    } else {
+        m_metadataModel.setHidden("qtBlendMode", true);
+        m_metadataModel.setHidden("blendMode", true);
+        m_metadataModel.setHidden("movitBlendMode", true);
+    }
+}
