@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022-2025 Meltytech, LLC
+ * Copyright (c) 2022-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,11 +39,13 @@
 
 class TextEditor : public QPlainTextEdit
 {
+    Q_DECLARE_TR_FUNCTIONS(TextEditor)
+
 public:
     explicit TextEditor(QWidget *parent = nullptr)
         : QPlainTextEdit()
     {
-        setObjectName(tr("Notes"));
+        setObjectName("Notes");
         zoomIn(Settings.notesZoom());
         setTabChangesFocus(false);
         setTabStopDistance(fontMetrics().horizontalAdvance("XXXX")); // Tabstop = 4 spaces
@@ -144,6 +146,7 @@ NotesDock::NotesDock(QWidget *parent)
                                         QIcon(":/icons/oxygen/32x32/actions/document-edit.png"));
     setWindowIcon(filterIcon);
     toggleViewAction()->setIcon(windowIcon());
+    setWhatsThis("https://forum.shotcut.org/t/notes-panel/33110/1");
 
     QObject::connect(m_textEdit, SIGNAL(textChanged()), SLOT(onTextChanged()));
     // Wrap the text editor with a container so we can place a toolbar beneath it.
