@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2024-2025 Meltytech, LLC
+ * Copyright (c) 2024-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -136,6 +136,7 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
                                         QIcon(":/icons/oxygen/32x32/actions/subtitle.png"));
     setWindowIcon(filterIcon);
     toggleViewAction()->setIcon(windowIcon());
+    setWhatsThis("https://forum.shotcut.org/t/subtitles-panel/45312/1");
 
     setupActions();
 
@@ -194,7 +195,9 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     mainMenu->addAction(Actions["subtitleBurnInAction"]);
     mainMenu->addAction(Actions["subtitleGenerateTextAction"]);
     mainMenu->addAction(Actions["subtitleSpeechToTextAction"]);
+#ifdef EXTERNAL_LAUNCHERS
     mainMenu->addAction(Actions["subtitleTextToSpeechAction"]);
+#endif
     mainMenu->addAction(Actions["subtitleTrackTimelineAction"]);
     mainMenu->addAction(Actions["subtitleShowPrevNextAction"]);
 
@@ -264,10 +267,12 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     button->setAutoRaise(true);
     toolbar->addWidget(button);
 
+#ifdef EXTERNAL_LAUNCHERS
     button = new QToolButton;
     button->setDefaultAction(Actions["subtitleTextToSpeechAction"]);
     button->setAutoRaise(true);
     toolbar->addWidget(button);
+#endif
 
     vboxLayout->addWidget(toolbar);
 
@@ -282,7 +287,7 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     textLayout->addWidget(m_nextLabel, 0, 2);
     m_prev = new QTextEdit(this);
     m_prev->setMaximumHeight(textHeight);
-    m_prev->setReadOnly(true);
+    m_prev->setDisabled(true);
     m_prev->setLineWrapMode(QTextEdit::NoWrap);
     textLayout->addWidget(m_prev, 1, 0);
     m_text = new QTextEdit(this);
@@ -294,7 +299,7 @@ SubtitlesDock::SubtitlesDock(QWidget *parent)
     textLayout->addWidget(m_text, 1, 1);
     m_next = new QTextEdit(this);
     m_next->setMaximumHeight(textHeight);
-    m_next->setReadOnly(true);
+    m_next->setDisabled(true);
     m_next->setLineWrapMode(QTextEdit::NoWrap);
     textLayout->addWidget(m_next, 1, 2);
     vboxLayout->addLayout(textLayout);
@@ -434,12 +439,14 @@ void SubtitlesDock::setupActions()
     connect(action, &QAction::triggered, this, &SubtitlesDock::speechToText);
     Actions.add("subtitleSpeechToTextAction", action, windowTitle());
 
+#ifdef EXTERNAL_LAUNCHERS
     action = new QAction(tr("Text to Speech..."), this);
     action->setToolTip(tr("Convert the current subtitle track to spoken audio."));
     action->setIcon(
         QIcon::fromTheme("text-speak", QIcon(":/icons/oxygen/32x32/actions/text-speak.png")));
     connect(action, &QAction::triggered, this, &SubtitlesDock::textToSpeech);
     Actions.add("subtitleTextToSpeechAction", action, windowTitle());
+#endif
 
     action = new QAction(tr("Track Timeline Cursor"), this);
     action->setToolTip(tr("Track the timeline cursor"));
@@ -924,15 +931,15 @@ void SubtitlesDock::updateTextWidgets()
             m_text->setReadOnly(false);
             if (itemIndex > 0) {
                 item = m_model->getItem(trackIndex, itemIndex - 1);
-                m_prev->setPlaceholderText(QString::fromStdString(item.text));
+                m_prev->setText(QString::fromStdString(item.text));
             } else {
-                m_prev->setPlaceholderText(QString());
+                m_prev->setText(QString());
             }
             if (itemIndex < (m_model->itemCount(trackIndex) - 1)) {
                 item = m_model->getItem(trackIndex, itemIndex + 1);
-                m_next->setPlaceholderText(QString::fromStdString(item.text));
+                m_next->setText(QString::fromStdString(item.text));
             } else {
-                m_next->setPlaceholderText(QString());
+                m_next->setText(QString());
             }
             return;
         } else {
@@ -951,15 +958,15 @@ void SubtitlesDock::updateTextWidgets()
             m_text->setReadOnly(false);
             if (itemIndex > 0) {
                 item = m_model->getItem(trackIndex, itemIndex - 1);
-                m_prev->setPlaceholderText(QString::fromStdString(item.text));
+                m_prev->setText(QString::fromStdString(item.text));
             } else {
-                m_prev->setPlaceholderText(QString());
+                m_prev->setText(QString());
             }
             if (itemIndex < (m_model->itemCount(trackIndex) - 1)) {
                 item = m_model->getItem(trackIndex, itemIndex + 1);
-                m_next->setPlaceholderText(QString::fromStdString(item.text));
+                m_next->setText(QString::fromStdString(item.text));
             } else {
-                m_next->setPlaceholderText(QString());
+                m_next->setText(QString());
             }
         } else {
             m_text->clear();
@@ -1005,7 +1012,9 @@ void SubtitlesDock::updateActionAvailablity()
         Actions["subtitleBurnInAction"]->setEnabled(false);
         Actions["subtitleGenerateTextAction"]->setEnabled(false);
         Actions["subtitleSpeechToTextAction"]->setEnabled(false);
+#ifdef EXTERNAL_LAUNCHERS
         Actions["subtitleTextToSpeechAction"]->setEnabled(false);
+#endif
     } else {
         m_addToTimelineLabel->setVisible(false);
         Actions["subtitleCreateEditItemAction"]->setEnabled(true);
@@ -1014,7 +1023,9 @@ void SubtitlesDock::updateActionAvailablity()
         Actions["SubtitleImportAction"]->setEnabled(true);
         Actions["subtitleAddItemAction"]->setEnabled(true);
         Actions["subtitleSpeechToTextAction"]->setEnabled(true);
+#ifdef EXTERNAL_LAUNCHERS
         Actions["subtitleTextToSpeechAction"]->setEnabled(true);
+#endif
         if (m_model->trackCount() == 0) {
             Actions["subtitleRemoveTrackAction"]->setEnabled(false);
             Actions["SubtitleExportAction"]->setEnabled(false);
@@ -1024,7 +1035,9 @@ void SubtitlesDock::updateActionAvailablity()
             Actions["subtitleSetEndAction"]->setEnabled(false);
             Actions["subtitleBurnInAction"]->setEnabled(false);
             Actions["subtitleGenerateTextAction"]->setEnabled(false);
+#ifdef EXTERNAL_LAUNCHERS
             Actions["subtitleTextToSpeechAction"]->setEnabled(false);
+#endif
         } else {
             Actions["subtitleRemoveTrackAction"]->setEnabled(true);
             Actions["SubtitleExportAction"]->setEnabled(true);
