@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2023 Meltytech, LLC
+ * Copyright (c) 2014-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,18 +16,20 @@
  */
 
 #include "mltxmlchecker.h"
+
+#include "Logger.h"
 #include "mltcontroller.h"
-#include "shotcut_mlt_properties.h"
-#include "util.h"
 #include "proxymanager.h"
 #include "settings.h"
+#include "shotcut_mlt_properties.h"
+#include "util.h"
 
-#include <QLocale>
-#include <QDir>
 #include <QCoreApplication>
-#include <QUrl>
+#include <QDir>
+#include <QLocale>
 #include <QRegularExpression>
-#include <Logger.h>
+#include <QUrl>
+
 #include <clocale>
 #include <utime.h>
 
@@ -35,11 +37,9 @@ static QString getPrefix(const QString &name, const QString &value);
 
 static bool isMltClass(const QString &name)
 {
-    return name == "profile" || name == "producer" ||
-           name == "filter" || name == "playlist" ||
-           name == "tractor" || name == "track" ||
-           name == "transition" || name == "consumer" ||
-           name == "chain" || name == "link";
+    return name == "profile" || name == "producer" || name == "filter" || name == "playlist"
+           || name == "tractor" || name == "track" || name == "transition" || name == "consumer"
+           || name == "chain" || name == "link";
 }
 
 static bool isNetworkResource(const QString &string)
@@ -53,18 +53,19 @@ static bool isNetworkResource(const QString &string)
 
 static bool isNumericProperty(const QString &name)
 {
-    return  name == "length" || name == "geometry" ||
-            name == "rect" || name == "warp_speed";
+    return name == "length" || name == "geometry" || name == "rect" || name == "warp_speed";
 }
 
 MltXmlChecker::MltXmlChecker()
     : m_needsGPU(false)
     , m_needsCPU(false)
     , m_hasEffects(false)
+    , m_isConverted(false)
     , m_isCorrected(false)
     , m_isUpdated(false)
     , m_decimalPoint('.')
     , m_numericValueChanged(false)
+    , m_isTractorTransition(false)
 {
     m_unlinkedFilesModel.setColumnCount(ColumnCount);
 }
@@ -74,8 +75,7 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString &fileName)
     LOG_DEBUG() << "begin";
 
     QFile file(fileName);
-    m_tempFile.reset(new QTemporaryFile(
-                         QFileInfo(fileName).dir().filePath("shotcut-XXXXXX.mlt")));
+    m_tempFile.reset(new QTemporaryFile(QFileInfo(fileName).dir().filePath("shotcut-XXXXXX.mlt")));
     if (file.open(QIODevice::ReadOnly | QIODevice::Text) && m_tempFile->open()) {
         m_tempFile->resize(0);
         m_fileInfo = QFileInfo(fileName);
@@ -97,7 +97,8 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString &fileName)
                     } else if (a.name().toString().toLower() == "version") {
                         m_mltVersion = QVersionNumber::fromString(a.value());
                     } else if (a.name().toString().toLower() == "title") {
-                        m_newXml.writeAttribute(a.name().toString(), "Shotcut version " SHOTCUT_VERSION);
+                        m_newXml.writeAttribute(a.name().toString(),
+                                                "Shotcut version " SHOTCUT_VERSION);
                         auto parts = a.value().split(' ');
                         LOG_DEBUG() << parts;
                         if (parts.size() > 2 && parts[1].toString() == "version") {
@@ -112,7 +113,7 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString &fileName)
                 }
 
                 readMlt();
-                m_newXml.writeEndElement();
+                m_newXml.writeEndElement(); // </mlt>
                 m_newXml.writeEndDocument();
                 m_isCorrected = m_isCorrected || m_numericValueChanged;
             } else {
@@ -125,9 +126,9 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString &fileName)
         m_tempFile->close();
 
         // Useful for debugging
-//        m_tempFile->open();
-//        LOG_DEBUG() << m_tempFile->readAll().constData();
-//        m_tempFile->close();
+        //        m_tempFile->open();
+        //        LOG_DEBUG() << m_tempFile->readAll().constData();
+        //        m_tempFile->close();
     }
     LOG_DEBUG() << "end" << m_xml.errorString();
     return m_xml.error();
@@ -163,13 +164,14 @@ void MltXmlChecker::readMlt()
                                                 m_xml.processingInstructionData().toString());
             break;
         case QXmlStreamReader::StartDocument:
-            m_newXml.writeStartDocument(m_xml.documentVersion().toString(), m_xml.isStandaloneDocument());
+            m_newXml.writeStartDocument(m_xml.documentVersion().toString(),
+                                        m_xml.isStandaloneDocument());
             break;
         case QXmlStreamReader::EndDocument:
             m_newXml.writeEndDocument();
             break;
         case QXmlStreamReader::StartElement: {
-            const QString element = m_xml.name().toString();
+            const auto element = m_xml.name().toString();
             isPropertyElement = false;
             if (element == "property") {
                 isPropertyElement = true;
@@ -178,23 +180,39 @@ void MltXmlChecker::readMlt()
                     m_properties << MltProperty(name, m_xml.readElementText());
                 }
             } else {
+                if (element == "tractor")
+                    m_isTractorTransition = false;
                 processProperties();
                 m_newXml.writeStartElement(m_xml.namespaceUri().toString(), element);
-                if (isMltClass(m_xml.name().toString()))
+                if (isMltClass(element))
                     mlt_class = element;
                 checkInAndOutPoints(); // This also copies the attributes.
             }
             break;
         }
-        case QXmlStreamReader::EndElement:
-            if (m_xml.name().toString() != "property") {
+        case QXmlStreamReader::EndElement: {
+            const auto element = m_xml.name().toString();
+            if (element != "property") {
+                if (!m_isTractorTransition && element == "tractor") {
+                    if (m_isConverted) {
+                        m_newXml.writeStartElement("property");
+                        m_newXml.writeAttribute("name", kShotcutProjectProcessingMode);
+                        m_newXml.writeCharacters(m_needsGPU ? "Native8Cpu" : "Linear10GpuCpu");
+                        m_newXml.writeEndElement();
+
+                    } else if (!m_processingMode.isEmpty()) {
+                        m_newXml.writeStartElement("property");
+                        m_newXml.writeAttribute("name", kShotcutProjectProcessingMode);
+                        m_newXml.writeCharacters(m_processingMode);
+                        m_newXml.writeEndElement();
+                    }
+                }
                 processProperties();
                 m_newXml.writeEndElement();
-                if (isMltClass(m_xml.name().toString())) {
+                if (isMltClass(element))
                     mlt_class.clear();
-                }
             }
-            break;
+        } break;
         default:
             break;
         }
@@ -214,6 +232,14 @@ void MltXmlChecker::processProperties()
             mlt_service = p.second;
         } else if (p.first == kShotcutHashProperty) {
             m_resource.hash = p.second;
+        } else if (p.first.startsWith(kIsProxyProperty)) {
+            m_resource.isProxy = true;
+        } else if (p.first == kShotcutProjectProcessingMode) {
+            m_processingMode = p.second;
+            // Exclude it & rewrite at the end of the last tractor
+            continue;
+        } else if (p.first == kShotcutTransitionProperty) {
+            m_isTractorTransition = true;
         } else if (isNumericProperty(p.first)) {
             checkNumericString(p.second);
         } else if (p.first == "resource" && mlt_service == "webvfx" && fixWebVfxPath(p.second)) {
@@ -233,20 +259,23 @@ void MltXmlChecker::processProperties()
     }
 
     if (mlt_class == "filter" || mlt_class == "transition" || mlt_class == "producer"
-            || mlt_class == "chain" || mlt_class == "link") {
+        || mlt_class == "chain" || mlt_class == "link") {
         checkGpuEffects(mlt_service);
         checkCpuEffects(mlt_service);
         checkUnlinkedFile(mlt_service);
         checkIncludesSelf(newProperties);
         checkLumaAlphaOver(mlt_service, newProperties);
-#if LIBMLT_VERSION_INT >= ((6<<16)+(23<<8))
+        checkAudioGain(mlt_service, newProperties);
         replaceWebVfxCropFilters(mlt_service, newProperties);
         replaceWebVfxChoppyFilter(mlt_service, newProperties);
-#endif
-        if (Settings.proxyEnabled())
+        replaceMovitServices(mlt_service, newProperties);
+        bool proxyEnabled = Settings.proxyEnabled();
+        if (proxyEnabled)
             checkForProxy(mlt_service, newProperties);
 
         // Second pass: amend property values.
+        bool relinkMismatch = !m_resource.hash.isEmpty() && !m_resource.newHash.isEmpty()
+                              && m_resource.hash != m_resource.newHash;
         m_properties = newProperties;
         newProperties.clear();
         foreach (MltProperty p, m_properties) {
@@ -260,8 +289,24 @@ void MltXmlChecker::processProperties()
             } else if (p.first == kShotcutDetailProperty) {
                 // We no longer save this (leaks absolute paths).
                 p.second.clear();
-            } else if (p.first == "audio_index" || p.first == "video_index") {
-                fixStreamIndex(p);
+            } else if (relinkMismatch && p.first == "audio_index") {
+                // Reset stream index properties if re-linked file is different.
+                p.second = QString::number(m_resource.audio_index);
+            } else if (relinkMismatch && p.first == "astream") {
+                p.second = "0";
+            } else if (relinkMismatch && p.first == "video_index") {
+                p.second = QString::number(m_resource.video_index);
+            } else if (relinkMismatch && p.first == "vstream") {
+                p.second = "0";
+            } else if (relinkMismatch && p.first.startsWith("meta.")) {
+                // Remove meta properties if re-linked file is different.
+                p.second.clear();
+            } else if ((proxyEnabled && m_resource.notProxyMeta && p.first.startsWith("meta."))
+                       || (!proxyEnabled && m_resource.isProxy
+                           && (p.first == kIsProxyProperty || p.first.startsWith("meta.")))) {
+                // Remove meta properties if they misrepresent proxy/original
+                p.second.clear();
+                m_isUpdated = true;
             }
 
             if (!p.second.isEmpty())
@@ -299,8 +344,7 @@ void MltXmlChecker::checkInAndOutPoints()
 bool MltXmlChecker::checkNumericString(QString &value)
 {
     // Determine if there is a decimal point inconsistent with locale.
-    if (!value.contains(m_decimalPoint) &&
-            (value.contains('.') || value.contains(','))) {
+    if (!value.contains(m_decimalPoint) && (value.contains('.') || value.contains(','))) {
         value.replace(',', m_decimalPoint);
         value.replace('.', m_decimalPoint);
         m_numericValueChanged = true;
@@ -384,11 +428,10 @@ static QString getSuffix(const QString &name, const QString &value)
 bool MltXmlChecker::readResourceProperty(const QString &name, QString &value)
 {
     if (mlt_class == "filter" || mlt_class == "transition" || mlt_class == "producer"
-            || mlt_class == "chain" || mlt_class == "link")
-        if (name == "resource" || name == "src" || name == "filename"
-                || name == "luma" || name == "luma.resource" || name == "composite.luma"
-                || name == "producer.resource" || name == "av.file" || name == "warp_resource") {
-
+        || mlt_class == "chain" || mlt_class == "link")
+        if (name == "resource" || name == "src" || name == "filename" || name == "luma"
+            || name == "luma.resource" || name == "composite.luma" || name == "producer.resource"
+            || name == "av.file" || name == "warp_resource") {
             // Handle special prefix such as "plain:" or speed.
             m_resource.prefix = getPrefix(name, value);
             m_resource.suffix = getSuffix(name, value);
@@ -396,7 +439,8 @@ bool MltXmlChecker::readResourceProperty(const QString &name, QString &value)
             filePath = filePath.left(filePath.size() - m_resource.suffix.size());
             // Save the resource name (minus prefix) for later check for unlinked files.
             m_resource.info.setFile(filePath);
-            if (!isNetworkResource(value) && m_resource.info.isRelative() && !Util::hasDriveLetter(value))
+            if (!isNetworkResource(value) && m_resource.info.isRelative()
+                && !Util::hasDriveLetter(value))
                 m_resource.info.setFile(m_fileInfo.canonicalPath(), m_resource.info.filePath());
             return true;
         }
@@ -414,7 +458,8 @@ void MltXmlChecker::checkGpuEffects(const QString &mlt_service)
 
 void MltXmlChecker::checkCpuEffects(const QString &mlt_service)
 {
-    if (mlt_service.startsWith("frei0r.cairoblend") || mlt_service.startsWith("choppy"))
+    if (mlt_service.startsWith("qtblend") || mlt_service.startsWith("frei0r.cairoblend")
+        || mlt_service.startsWith("choppy"))
         m_needsCPU = true;
 }
 
@@ -436,16 +481,23 @@ void MltXmlChecker::checkUnlinkedFile(const QString &mlt_service)
                         // not an invalid blank
                         if (mlt_service != "blank" || fileName != "blank")
                             // not a URL
-                            if (!m_resource.info.filePath().isEmpty() && !isNetworkResource(m_resource.info.filePath()))
+                            if (!m_resource.info.filePath().isEmpty()
+                                && !isNetworkResource(m_resource.info.filePath()))
                                 // not an image sequence
-                                if ((mlt_service != "pixbuf" && mlt_service != "qimage") || fileName.indexOf('%') == -1)
+                                if ((mlt_service != "pixbuf" && mlt_service != "qimage")
+                                    || fileName.indexOf('%') == -1)
                                     // file does not exist
                                     if (!m_resource.info.exists())
                                         // not already in the model
-                                        if (m_unlinkedFilesModel.findItems(filePath,
-                                                                           Qt::MatchFixedString | Qt::MatchCaseSensitive).isEmpty()) {
-                                            LOG_ERROR() << "file not found: " << m_resource.info.filePath();
-                                            QIcon icon(":/icons/oxygen/32x32/status/task-reject.png");
+                                        if (m_unlinkedFilesModel
+                                                .findItems(filePath,
+                                                           Qt::MatchFixedString
+                                                               | Qt::MatchCaseSensitive)
+                                                .isEmpty()) {
+                                            LOG_ERROR()
+                                                << "file not found: " << m_resource.info.filePath();
+                                            QIcon icon(
+                                                ":/icons/oxygen/32x32/status/task-reject.png");
                                             QStandardItem *item = new QStandardItem(icon, filePath);
                                             item->setToolTip(item->text());
                                             item->setData(m_resource.hash, ShotcutHashRole);
@@ -458,9 +510,9 @@ bool MltXmlChecker::fixUnlinkedFile(QString &value)
     // Replace unlinked files if model is populated with replacements.
     for (int row = 0; row < m_unlinkedFilesModel.rowCount(); ++row) {
         const QStandardItem *replacement = m_unlinkedFilesModel.item(row, ReplacementColumn);
-        if (replacement && !replacement->text().isEmpty() &&
-                m_unlinkedFilesModel.item(row,
-                                          MissingColumn)->text() == QDir::toNativeSeparators(m_resource.info.filePath())) {
+        if (replacement && !replacement->text().isEmpty()
+            && m_unlinkedFilesModel.item(row, MissingColumn)->text()
+                   == QDir::toNativeSeparators(m_resource.info.filePath())) {
             m_resource.info.setFile(replacement->text());
             m_resource.newDetail = replacement->text();
             m_resource.newHash = replacement->data(ShotcutHashRole).toString();
@@ -484,19 +536,6 @@ bool MltXmlChecker::fixUnlinkedFile(QString &value)
     return false;
 }
 
-void MltXmlChecker::fixStreamIndex(MltProperty &property)
-{
-    // Remove a stream index property if re-linked file is different.
-    if (!m_resource.hash.isEmpty() && !m_resource.newHash.isEmpty()
-            && m_resource.hash != m_resource.newHash) {
-        if (property.first == "audio_index") {
-            property.second = QString::number(m_resource.audio_index);
-        } else if (property.first == "video_index") {
-            property.second = QString::number(m_resource.video_index);
-        }
-    }
-}
-
 bool MltXmlChecker::fixVersion1701WindowsPathBug(QString &value)
 {
     if (value.size() >= 3 && value[0] == '/' && value[2] == ':') {
@@ -522,6 +561,203 @@ void MltXmlChecker::checkIncludesSelf(QVector<MltProperty> &properties)
     }
 }
 
+void MltXmlChecker::checkAudioGain(const QString &mlt_service, QVector<MltProperty> &properties)
+{
+    if (mlt_service == "volume") {
+        bool found = false;
+        for (auto &p : properties) {
+            if (p.first == kShotcutFilterProperty) {
+                found = true;
+            }
+        }
+        if (!found) {
+            properties << MltProperty(kShotcutFilterProperty, "audioGain");
+            m_isUpdated = true;
+        }
+    }
+}
+
+void MltXmlChecker::replaceMovitServices(QString &mlt_service, QVector<MltProperty> &properties)
+{
+    auto new_mlt_service = mlt_service;
+    QString newFilterName;
+    if (Settings.playerGPU()) {
+        // Only convert the transitions (including track blenders).
+        // CPU filters still work in GPU mode, and the user can chooose to replace them.
+        if (mlt_service == "luma") {
+            new_mlt_service = "movit.luma_mix";
+        } else if (mlt_service == "qtblend") {
+            new_mlt_service = "movit.overlay";
+        }
+    } else {
+        if (mlt_service == "movit.blur") {
+            new_mlt_service = "avfilter.gblur";
+            newFilterName = "blur_gaussian_av";
+            for (auto &p : properties) {
+                if (p.first == "radius") {
+                    p.first = "av.sigma";
+                    properties << MltProperty("av.sigmaV", p.second);
+                    break;
+                }
+            }
+            properties << MltProperty(kShotcutFilterProperty, newFilterName);
+        } else if (mlt_service == "crop") {
+            new_mlt_service = "crop";
+            for (auto &p : properties) {
+                if (p.first == kShotcutFilterProperty) {
+                    properties.removeOne(p);
+                    break;
+                }
+            }
+        } else if (mlt_service == "movit.diffusion") {
+            new_mlt_service = "avfilter.smartblur";
+            // not really convertible, but replace with smartblur's defaults
+            for (auto &p : properties) {
+                if (p.first == "radius") {
+                    p.first = "av.luma_radius";
+                    p.second = "2.5";
+                } else if (p.first == "mix") {
+                    p.first = "av.luma_strength";
+                    p.second = "0.5";
+                }
+            }
+            properties << MltProperty("av.chroma_radius", "2.5");
+            properties << MltProperty("av.chroma_strength", "0.5");
+            properties << MltProperty("av.luma_threshold", "3");
+            properties << MltProperty("av.chroma_threshold", "3");
+        } else if (mlt_service == "movit.flip") {
+            new_mlt_service = "avfilter.vflip";
+        } else if (mlt_service == "movit.glow") {
+            new_mlt_service = "frei0r.glow";
+            for (auto &p : properties) {
+                if (p.first == "radius") {
+                    p.first = "0";
+                    p.second = QString::number(p.second.toFloat() / 100.0);
+                    break;
+                }
+            }
+        } else if (mlt_service == "movit.lift_gamma_gain") {
+            new_mlt_service = "lift_gamma_gain";
+            for (auto &p : properties) {
+                if (p.first == kShotcutFilterProperty && p.second == "movitContrast") {
+                    newFilterName = "contrast";
+                    break;
+                }
+            }
+        } else if (mlt_service == "movit.luma_mix") {
+            new_mlt_service = "luma";
+        } else if (mlt_service == "movit.mirror") {
+            new_mlt_service = "avfilter.hflip";
+        } else if (mlt_service == "movit.opacity") {
+            new_mlt_service = "brightness";
+            QString alpha;
+            for (auto &p : properties) {
+                if (p.first == kShotcutFilterProperty) {
+                    if (p.second == "fadeInMovit" || p.second == "fadeOutMovit") {
+                        newFilterName = p.second;
+                        newFilterName.replace("Movit", "Brightness");
+                        for (auto &p2 : properties) {
+                            if (p2.first == "alpha") {
+                                alpha = p2.second;
+                                if (alpha == "-1")
+                                    p2.first = "level";
+                                p2.second = "1";
+                                break;
+                            }
+                        }
+                    } else if (p.second == "movitOpacity") {
+                        newFilterName = "brightnessOpacity";
+                    } else {
+                        // Brightness filter, cause "opacity" to be converted to "level" below
+                        alpha = "1";
+                    }
+                    break;
+                }
+            }
+            if (alpha == "-1") {
+                // Fade opacity
+                for (auto &p : properties) {
+                    if (p.first == "opacity") {
+                        p.first = "alpha";
+                        break;
+                    }
+                }
+            } else if (!alpha.isEmpty()) {
+                // Fade with black
+                for (auto &p : properties) {
+                    if (p.first == "opacity") {
+                        p.first = "level";
+                        break;
+                    }
+                }
+            }
+        } else if (mlt_service == "movit.overlay") {
+            new_mlt_service = "qtblend";
+        } else if (mlt_service == "movit.rect") {
+            new_mlt_service = "affine";
+            newFilterName = "affineSizePosition";
+            for (auto &p : properties) {
+                if (p.first == "fill" || p.first == "distort" || p.first == "rect"
+                    || p.first == "valign" || p.first == "halign")
+                    p.first.prepend("transition.");
+            }
+        } else if (mlt_service == "movit.saturation") {
+            new_mlt_service = "frei0r.saturat0r";
+            for (auto &p : properties) {
+                if (p.first == "saturation") {
+                    p.first = "0";
+                    p.second = QString::number(p.second.toFloat() / 3.0 * 0.375);
+                    break;
+                }
+            }
+        } else if (mlt_service == "movit.sharpen") {
+            new_mlt_service = "frei0r.sharpness";
+            // not really convertible; setting to frei0r filter's default values
+            for (auto &p : properties) {
+                if (p.first == "circle_radius") {
+                    p.first = "0";
+                    p.second = "0.5";
+                } else if (p.first == "gaussian_radius") {
+                    p.first = "1";
+                    p.second = "0.5";
+                }
+            }
+        } else if (mlt_service == "movit.vignette") {
+            new_mlt_service = "vignette";
+            // not really convertible; setting to frei0r filter's default values
+            for (auto &p : properties) {
+                if (p.first == "radius") {
+                    p.first = "0";
+                    p.second = "0.5";
+                } else if (p.first == "inner_radius") {
+                    p.first = "1";
+                    p.second = "0.5";
+                }
+            }
+        } else if (mlt_service == "movit.white_balance") {
+            new_mlt_service = "frei0r.colgate";
+            for (auto &p : properties) {
+                if (p.first == "neutral_color") {
+                    p.first = "0";
+                } else if (p.first == "color_temperature") {
+                    p.first = "1";
+                    p.second = QString::number(p.second.toFloat() / 15000.0);
+                }
+            }
+        }
+    }
+    if (new_mlt_service != mlt_service) {
+        for (auto &p : properties) {
+            if (p.first == "mlt_service") {
+                p.second = new_mlt_service;
+                m_isConverted = true;
+            } else if (p.first == kShotcutFilterProperty) {
+                p.second = newFilterName;
+            }
+        }
+    }
+}
+
 void MltXmlChecker::checkLumaAlphaOver(const QString &mlt_service,
                                        QVector<MltXmlChecker::MltProperty> &properties)
 {
@@ -545,13 +781,13 @@ void MltXmlChecker::replaceWebVfxCropFilters(QString &mlt_service,
     if (mlt_service == "webvfx") {
         auto isCrop = false;
         for (auto &p : properties) {
-            if (p.first == "shotcut:filter" && p.second == "webvfxCircularFrame") {
+            if (p.first == kShotcutFilterProperty && p.second == "webvfxCircularFrame") {
                 p.second = "cropCircle";
                 properties << MltProperty("circle", "1");
                 m_isUpdated = isCrop = true;
                 break;
             }
-            if (p.first == "shotcut:filter" && p.second == "webvfxClip") {
+            if (p.first == kShotcutFilterProperty && p.second == "webvfxClip") {
                 p.second = "cropRectangle";
                 m_isUpdated = isCrop = true;
                 break;
@@ -582,7 +818,7 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString &mlt_service,
         auto isChoppy = false;
         QString shotcutFilter;
         for (auto &p : properties) {
-            if (p.first == "shotcut:filter") {
+            if (p.first == kShotcutFilterProperty) {
                 shotcutFilter = p.second;
                 if (p.second == "webvfxChoppy") {
                     properties.removeOne(p);
@@ -633,7 +869,7 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString &mlt_service,
                     break;
                 }
             }
-            properties << MltProperty("shotcut:filter", "richText");
+            properties << MltProperty(kShotcutFilterProperty, "richText");
         }
     }
 }
@@ -667,10 +903,30 @@ void MltXmlChecker::checkForProxy(const QString &mlt_service,
                 if (p.first == "resource") {
                     p.second = ProxyManager::GoProProxyFilePath(resource);
                     if (isTimewarp) {
-                        p.second = QString("%1:%2").arg(speed).arg(p.second);
+                        p.second = QStringLiteral("%1:%2").arg(speed, p.second);
                     }
                     properties << MltProperty(kIsProxyProperty, "1");
+                    properties << MltProperty(kMetaProxyProperty, "1");
                     properties << MltProperty(kOriginalResourceProperty, resource);
+                    m_resource.notProxyMeta = !m_resource.isProxy;
+                    m_isUpdated = true;
+                    return;
+                }
+            }
+        }
+
+        // Use DJI LRF if available
+        if (QFile::exists(ProxyManager::DJIProxyFilePath(resource))) {
+            for (auto &p : properties) {
+                if (p.first == "resource") {
+                    p.second = ProxyManager::DJIProxyFilePath(resource);
+                    if (isTimewarp) {
+                        p.second = QStringLiteral("%1:%2").arg(speed, p.second);
+                    }
+                    properties << MltProperty(kIsProxyProperty, "1");
+                    properties << MltProperty(kMetaProxyProperty, "1");
+                    properties << MltProperty(kOriginalResourceProperty, resource);
+                    m_resource.notProxyMeta = !m_resource.isProxy;
                     m_isUpdated = true;
                     return;
                 }
@@ -692,13 +948,15 @@ void MltXmlChecker::checkForProxy(const QString &mlt_service,
                         p.second = proxyDir.filePath(fileName);
                     }
                     if (isTimewarp) {
-                        p.second = QString("%1:%2").arg(speed).arg(p.second);
+                        p.second = QStringLiteral("%1:%2").arg(speed, p.second);
                     }
                     break;
                 }
             }
             properties << MltProperty(kIsProxyProperty, "1");
+            properties << MltProperty(kMetaProxyProperty, "1");
             properties << MltProperty(kOriginalResourceProperty, resource);
+            m_resource.notProxyMeta = !m_resource.isProxy;
             m_isUpdated = true;
         }
     } else if ((mlt_service == "qimage" || mlt_service == "pixbuf")
@@ -735,7 +993,9 @@ void MltXmlChecker::checkForProxy(const QString &mlt_service,
                 }
             }
             properties << MltProperty(kIsProxyProperty, "1");
+            properties << MltProperty(kMetaProxyProperty, "1");
             properties << MltProperty(kOriginalResourceProperty, resource);
+            m_resource.notProxyMeta = !m_resource.isProxy;
             m_isUpdated = true;
         }
     }
