@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2025 Meltytech, LLC
+ * Copyright (c) 2013-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <QApplication>
 #include <QAudioDevice>
 #include <QColor>
+#include <QColorDialog>
 #include <QDir>
 #include <QFile>
 #include <QLocale>
@@ -39,6 +40,21 @@ static const int kMaximumTrackHeight = 125;
 static const QString kRecentKey("recent");
 static const QString kProjectsKey("projects");
 
+namespace {
+struct ModeMap
+{
+    ShotcutSettings::ProcessingMode id;
+    const char *name;
+};
+static const ModeMap kModeMap[] = {
+    {ShotcutSettings::Native8Cpu, "Native8Cpu"},
+    {ShotcutSettings::Linear8Cpu, "Linear8Cpu"},
+    {ShotcutSettings::Native10Cpu, "Native10Cpu"},
+    {ShotcutSettings::Linear10Cpu, "Linear10Cpu"},
+    {ShotcutSettings::Linear10GpuCpu, "Linear10GpuCpu"},
+};
+} // anonymous namespace
+
 ShotcutSettings &ShotcutSettings::singleton()
 {
     if (!instance) {
@@ -493,6 +509,16 @@ void ShotcutSettings::setEncodeHardware(const QStringList &ls)
         settings.setValue("encode/hardware", ls);
 }
 
+bool ShotcutSettings::encodeHardwareDecoder() const
+{
+    return settings.value("encode/hardwareDecoder", false).toBool();
+}
+
+void ShotcutSettings::setEncodeHardwareDecoder(bool b)
+{
+    settings.setValue("encode/hardwareDecoder", b);
+}
+
 bool ShotcutSettings::encodeAdvanced() const
 {
     return settings.value("encode/advanced", false).toBool();
@@ -513,6 +539,51 @@ void ShotcutSettings::setConvertAdvanced(bool b)
     settings.setValue("convertAdvanced", b);
 }
 
+ShotcutSettings::ProcessingMode ShotcutSettings::processingMode()
+{
+    if (settings.contains("processingMode")) {
+        auto result = (ShotcutSettings::ProcessingMode) settings.value("processingMode").toInt();
+        if (result == Linear8Cpu) {
+            // No longer supported but kept to prevent unexpected processing behavior going from
+            // beta to release
+            result = Native8Cpu;
+        }
+        return result;
+    } else if (settings.contains("player/gpu2")) {
+        // Legacy GPU Mode
+        if (settings.value("player/gpu2").toBool()) {
+            return ShotcutSettings::Linear10GpuCpu;
+        }
+    }
+    return ShotcutSettings::Native8Cpu;
+}
+
+void ShotcutSettings::setProcessingMode(ProcessingMode mode)
+{
+    settings.setValue("processingMode", mode);
+    emit playerGpuChanged();
+}
+
+QString ShotcutSettings::processingModeStr(ShotcutSettings::ProcessingMode mode)
+{
+    for (const auto &m : kModeMap) {
+        if (m.id == mode)
+            return QString::fromLatin1(m.name);
+    }
+    LOG_ERROR() << "Unknown processing mode" << mode;
+    return QStringLiteral("Native8Cpu");
+}
+
+ShotcutSettings::ProcessingMode ShotcutSettings::processingModeId(const QString &mode)
+{
+    for (const auto &m : kModeMap) {
+        if (mode == QLatin1String(m.name))
+            return m.id;
+    }
+    LOG_ERROR() << "Unknown processing mode" << mode;
+    return Native8Cpu;
+}
+
 bool ShotcutSettings::showConvertClipDialog() const
 {
     return settings.value("showConvertClipDialog", true).toBool();
@@ -570,12 +641,6 @@ void ShotcutSettings::setPlayerExternal(const QString &s)
     settings.setValue("player/external", s);
 }
 
-void ShotcutSettings::setPlayerGPU(bool b)
-{
-    settings.setValue("player/gpu2", b);
-    emit playerGpuChanged();
-}
-
 bool ShotcutSettings::playerJACK() const
 {
     return settings.value("player/jack", false).toBool();
@@ -593,7 +658,15 @@ void ShotcutSettings::setPlayerInterpolation(const QString &s)
 
 bool ShotcutSettings::playerGPU() const
 {
-    return settings.value("player/gpu2", false).toBool();
+    // This is the legacy function for the old GPU mode.
+    if (settings.contains("processingMode")) {
+        ProcessingMode mode = (ProcessingMode) settings.value("processingMode").toInt();
+        return mode == Linear10GpuCpu;
+    } else if (settings.contains("player/gpu2")) {
+        // Legacy GPU Mode
+        return settings.value("player/gpu2").toBool();
+    }
+    return false;
 }
 
 bool ShotcutSettings::playerWarnGPU() const
@@ -706,6 +779,16 @@ void ShotcutSettings::setPlayerPreviewScale(int i)
     settings.setValue("player/previewScale", i);
 }
 
+bool ShotcutSettings::playerPreviewHardwareDecoder() const
+{
+    return settings.value("player/previewHardwareDecoder", true).toBool();
+}
+
+void ShotcutSettings::setPlayerPreviewHardwareDecoder(bool b)
+{
+    settings.setValue("player/previewHardwareDecoder", b);
+}
+
 int ShotcutSettings::playerVideoDelayMs() const
 {
     return settings.value("player/videoDelayMs", 0).toInt();
@@ -942,7 +1025,7 @@ ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
 
 bool ShotcutSettings::timelineAutoAddTracks() const
 {
-    return settings.value("timeline/autoAddTracks", true).toBool();
+    return settings.value("timeline/autoAddTracks", false).toBool();
 }
 
 void ShotcutSettings::setTimelineAutoAddTracks(bool b)
@@ -1553,6 +1636,36 @@ void ShotcutSettings::setSpeechSpeed(double speed)
     settings.setValue("speech/speed", speed);
 }
 
+void ShotcutSettings::saveCustomColors()
+{
+    // QColorDialog supports up to 48 custom colors (16 in older versions)
+    QStringList colorList;
+    for (int i = 0; i < QColorDialog::customCount(); ++i) {
+        QColor color = QColorDialog::customColor(i);
+        if (color.isValid()) {
+            colorList.append(color.name(QColor::HexArgb));
+        } else {
+            colorList.append(QString());
+        }
+    }
+    settings.setValue("colorDialog/customColors", colorList);
+}
+
+void ShotcutSettings::restoreCustomColors()
+{
+    QStringList colorList = settings.value("colorDialog/customColors").toStringList();
+    for (int i = 0; i < colorList.size() && i < QColorDialog::customCount(); ++i) {
+        const QString &colorName = colorList.at(i);
+        if (!colorName.isEmpty()) {
+            QColor color(colorName);
+            if (color.isValid()) {
+                // Use rgba() to preserve alpha channel
+                QColorDialog::setCustomColor(i, color.rgba());
+            }
+        }
+    }
+}
+
 void ShotcutSettings::setWhisperExe(const QString &path)
 {
     settings.setValue("subtitles/whisperExe", path);
@@ -1659,7 +1772,7 @@ void ShotcutSettings::setDockerPath(const QString &path)
 QString ShotcutSettings::chromiumPath() const
 {
 #if defined(Q_OS_MAC)
-    return settings.value("dockerPath", "/Applications/Google Chrome.app").toString();
+    return settings.value("chromiumPath", "/Applications/Google Chrome.app").toString();
 #elif defined(Q_OS_WIN)
     return settings.value("chromiumPath", "C:/Program Files/Google/Chrome/Application/chrome.exe")
         .toString();
